Crate paysec_keyblock

Crate paysec_keyblock 

Modules

header_constants
tr31_header_constants

Structs

KeyBlockHeader
Represents a TR-31 key block header.
OptBlock
Represent an optional block as defined by TR-31.
SecretKey
Plaintext cryptographic key material owned by paysec-keyblock.

Enums

KeyBlockHeaderError
Errors produced while constructing, parsing, validating, or serializing a TR-31 key block header.
OptBlockError
Errors produced while constructing, parsing, or serializing TR-31 optional blocks.
PayloadError
Errors produced while constructing or parsing a TR-31 payload.
Tr31CryptoError
Error returned by TR-31 operations that may invoke a cryptographic provider.
Tr31Error
Errors produced by TR-31 key block processing.

Functions

calculate_padding_length
Calculate the padding length required for a TR-31 payload.
tr31_unwrap
Unwrap a cryptographic key from a TR-31 key block version D.
tr31_wrap
Wrap a cryptographic key according to TR-31 key block version D.
tr31_wrap_with_header_string
Wrap a cryptographic key according to TR-31 version D using a header supplied as a string.