OptBlockError

Enum OptBlockError 

pub enum OptBlockError {
Show 16 variants StringTooShort { minimum: usize, actual: usize, }, NonAsciiInput, ExtendedLengthStringTooShort { minimum: usize, actual: usize, }, StringTooShortForLength { required: usize, actual: usize, }, Uninitialized { length: usize, }, InvalidId(String), IdNotSet, NonAsciiData(String), BlockTooLong { maximum: usize, actual: usize, }, InvalidLengthFieldWidth { value: String, expected: usize, }, InvalidLengthFieldHex { value: String, source: ParseIntError, }, LengthFieldTooSmall { minimum: usize, actual: usize, }, InvalidExtendedLengthField(String), InvalidLengthOfLengthField(String), InvalidExtendedLengthHex { value: String, source: ParseIntError, }, ExtendedLengthTooSmall { value: String, },
}
Errors produced while constructing, parsing, or serializing TR-31 optional blocks.

Variants



StringTooShort

The supplied optional-block string does not contain the minimum ID and length fields.

Fields

minimum: usize
actual: usize


NonAsciiInput

Optional blocks are defined using ASCII data and cannot safely be parsed from arbitrary UTF-8 strings.



ExtendedLengthStringTooShort

An extended-length optional block must contain at least 256 bytes.

Fields

minimum: usize
actual: usize


StringTooShortForLength

The encoded optional-block length exceeds the available input.

Fields

required: usize
actual: usize


Uninitialized

An optional block has not been initialized sufficiently for export.

Fields

length: usize


InvalidId(String)

The optional-block identifier is not supported.



IdNotSet

Data was assigned before an optional-block identifier.



NonAsciiData(String)

Optional-block data contains non-ASCII characters.



BlockTooLong

The complete optional block exceeds the maximum representable size.

Fields

maximum: usize
actual: usize


InvalidLengthFieldWidth

A normal length field must consist of exactly two hexadecimal characters.

Fields

value: String
expected: usize


InvalidLengthFieldHex

A normal length field is not valid hexadecimal.

Fields

value: String


LengthFieldTooSmall

A normal optional-block length cannot be smaller than four bytes.

Fields

minimum: usize
actual: usize


InvalidExtendedLengthField(String)

An extended length field must consist of exactly six characters.



InvalidLengthOfLengthField(String)

The first two characters of the extended length field must encode the supported length-of-length value.



InvalidExtendedLengthHex

The extended block length is not valid hexadecimal.

Fields

value: String


ExtendedLengthTooSmall

Extended encoding may only be used for block lengths greater than 255 bytes.

Fields

value: String