pub enum PayloadError {
InvalidCipherBlockLength,
InvalidTotalPayloadLength,
KeyTooLong {
max: usize,
actual: usize,
},
RandomSeedTooShort {
required: usize,
actual: usize,
},
PayloadTooShort {
minimum: usize,
actual: usize,
},
PayloadTooShortForKey {
required: usize,
actual: usize,
},
}Expand description
Errors produced while constructing or parsing a TR-31 payload.
Variants
InvalidCipherBlockLength
The cipher block length must be greater than zero.
InvalidTotalPayloadLength
The calculated payload length is invalid.
KeyTooLong
The protected key is too large for the TR-31 16-bit key-length field.
RandomSeedTooShort
The supplied random seed does not contain enough bytes for padding.
PayloadTooShort
The payload does not contain the two-byte key-length field.
PayloadTooShortForKey
The payload does not contain as many key bytes as its length field declares.