Tr31Error

Enum Tr31Error 

pub enum Tr31Error {
    UnsupportedVersion(String),
    TotalBlockLengthNotMultiple {
        block_length: usize,
        actual: usize,
    },
    KeyBlockLengthMismatch {
        expected: usize,
        actual: usize,
    },
    KeyBlockBelowMinimum {
        minimum: usize,
        actual: usize,
    },
    InvalidMacLength {
        expected: usize,
        actual: usize,
    },
    MacVerificationFailed,
    Header(KeyBlockHeaderError),
    Payload(PayloadError),
    Hex(FromHexError),
    KeyBlockLengthTooLarge {
        maximum: usize,
        actual: usize,
    },
}
Errors produced by TR-31 key block processing.

Variants



UnsupportedVersion(String)

The requested key block version is not supported by this implementation.



TotalBlockLengthNotMultiple

The complete key block length is not aligned to the cipher block size.

Fields

block_length: usize
actual: usize


KeyBlockLengthMismatch

The actual key block length differs from the value encoded in the header.

Fields

expected: usize
actual: usize


KeyBlockBelowMinimum

The key block is shorter than the minimum valid version D block.

Fields

minimum: usize
actual: usize


InvalidMacLength

The decoded MAC does not have the required length.

Fields

expected: usize
actual: usize


MacVerificationFailed

Key block authentication failed.



Header(KeyBlockHeaderError)

Header processing failed.



Payload(PayloadError)

Payload processing failed.



Hex(FromHexError)

Hexadecimal decoding failed.



KeyBlockLengthTooLarge

Fields

maximum: usize
actual: usize